@@ -19,7 +19,7 @@ if __name__ == "__main__":
         print('export DAWEBSERVER="nginx"')
     if '--limited' in sys.argv:
         sys.exit(0)
-    if 'other os locales' in daconfig and type(daconfig['other os locales']) is list:
+    if 'other os locales' in daconfig and isinstance(daconfig['other os locales'], list):
         print('declare -a OTHERLOCALES')
         print('export OTHERLOCALES')
         indexno = 0
@@ -61,7 +61,7 @@ if __name__ == "__main__":
             for package in map(lambda x: x.strip(), separator.split(packages_variable)):
                 print('PACKAGES[' + str(indexno) + ']=' + repr(str(package)))
                 indexno += 1
-    if 'python packages' in daconfig and type(daconfig['python packages']) is list:
+    if 'python packages' in daconfig and isinstance(daconfig['python packages'], list):
         print('declare -a PYTHONPACKAGES')
         print('export PYTHONPACKAGES')
         indexno = 0
